@@ -58,6 +58,12 @@ class plot:
             self.plt.style.use(self.style)
         self.fig = self.plt.figure(figsize=self.figsize)
 
+    def method_camera(self):
+        if not isinstance(self.azim, type(None)):
+            self.ax.view_init(azim=self.azim)
+        if not isinstance(self.elev, type(None)):
+            self.ax.view_init(azim=self.elev)
+
     def method_style(self):
         if self.light:
             self.workspace_color = 'black' if isinstance(self.workspace_color, type(None)) else self.workspace_color
@@ -75,6 +81,9 @@ class plot:
                 None)) else self.workspace_color2
             self.style = None
 
+        self.plt.rcParams["font.family"] = "serif"
+        self.plt.rcParams["mathtext.fontset"] = "dejavuserif"
+
     def method_legend(self):
         if self.legend is True:
             legend_font = font_manager.FontProperties(family=self.font,
@@ -86,7 +95,7 @@ class plot:
 
     def method_resize_axes(self):
         if self.resize_axes is True:
-            self.z_pad = self.z_pad if self.z_pad > (abs(self.z.max()) + abs(self.z.min())) / 16 else (abs(self.z.max()) + abs(self.z.min())) / 16
+            # self.z_pad = self.z_pad if self.z_pad > (abs(self.z.max()) + abs(self.z.min())) / 16 else (abs(self.z.max()) + abs(self.z.min())) / 16
             if isinstance(self.x_bounds, type(None)):
                 self.x_bounds = (self.x.min(), self.x.max())
             if isinstance(self.y_bounds, type(None)):
@@ -113,31 +122,26 @@ class plot:
 
     def method_title(self):
         if not isinstance(self.title, type(None)):
-            if self.title_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_title(self.title, y=self.title_y, fontname=self.font, weight=weight,
-                              color=self.workspace_color, size=self.title_size)
+
+            self.ax.set_title(self.title, y=self.title_y,
+                              fontname=self.font if isinstance(self.title_font, type(None)) else self.title_font,
+                              weight=self.title_weight,
+                              color=self.workspace_color if isinstance(self.title_color, type(None)) else self.title_color,
+                              size=self.title_size)
             self.ax.title.set_position((0.5, self.title_y))
 
     def method_axis_labels(self):
         if not isinstance(self.x_label, type(None)):
-            if self.x_label_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_xlabel(self.x_label, fontname=self.font, weight=weight,
+
+            self.ax.set_xlabel(self.x_label, fontname=self.font, weight=self.x_label_weight,
                                color=self.workspace_color, size=self.x_label_size, labelpad=self.x_label_pad,
                                rotation=self.x_label_rotation)
         if not isinstance(self.y_label, type(None)):
-            if self.y_label_bold is True:
-                weight = 'bold'
-            else:
-                weight = 'normal'
-            self.ax.set_ylabel(self.y_label, fontname=self.font, weight=weight,
+
+            self.ax.set_ylabel(self.y_label, fontname=self.font, weight=self.y_label_weight,
                                color=self.workspace_color, size=self.y_label_size, labelpad=self.y_label_pad,
                                rotation=self.y_label_rotation)
+
         if not isinstance(self.z_label, type(None)):
             if self.z_label_bold is True:
                 weight = 'bold'
@@ -339,9 +343,9 @@ class line(plot, dim_01):
                  y=None, y_scale=1,
                  z=None, z_scale=1,
                  # Base
-                 backend='Qt5Agg', plot_label='Plot', font='serif',
+                 backend='Qt5Agg', plot_label='Line', font='serif',
                  # Figure, axis
-                 fig=None, ax=None, figsize=None, shape_and_position=111,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=None, elev=None,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10, spines_removed=('top', 'right'),
                  workspace_color=None, workspace_color2=None, light=None, dark=None, pane_fill=None,
@@ -355,11 +359,11 @@ class line(plot, dim_01):
                  color='darkred', cmap='RdBu_r', alpha=None,
                  # Bounds
                  # Title
-                 title='Title', title_bold=False, title_size=12, title_y=1.025,
+                 title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=5, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=5, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=5, z_label_rotation=None,
+                 x_label=None, x_label_weight=None, x_label_size=12, x_label_pad=5, x_label_rotation=None,
+                 y_label=None, y_label_weight=None, y_label_size=12, y_label_pad=5, y_label_rotation=None,
+                 z_label=None, z_label_weight=None, z_label_size=12, z_label_pad=5, z_label_rotation=None,
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
@@ -379,115 +383,14 @@ class line(plot, dim_01):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=False, newplot=False,
+                 more_subplots_left=True,
                  # Save
                  filename=None, dpi=None,
                  ):
 
         """
-
-        @param line_width:
-        @param x:
-        @param x_scale:
-        @param y:
-        @param y_scale:
-        @param z:
-        @param z_scale:
-        @param backend:
-        @param plot_label:
-        @param font:
-        @param fig:
-        @param ax:
-        @param figsize:
-        @param shape_and_position:
-        @param prune:
-        @param resize_axes:
-        @param aspect:
-        @param box_to_plot_pad:
-        @param spines_removed:
-        @param workspace_color:
-        @param workspace_color2:
-        @param light:
-        @param dark:
-        @param pane_fill:
-        @param x_bounds:
-        @param y_bounds:
-        @param z_bounds:
-        @param x_pad:
-        @param y_pad:
-        @param z_pad:
-        @param grid:
-        @param grid_color:
-        @param grid_lines:
-        @param color:
-        @param cmap:
-        @param alpha:
-        @param title:
-        @param title_bold:
-        @param title_size:
-        @param title_y:
-        @param x_label:
-        @param x_label_bold:
-        @param x_label_size:
-        @param x_label_pad:
-        @param x_label_rotation:
-        @param y_label:
-        @param y_label_bold:
-        @param y_label_size:
-        @param y_label_pad:
-        @param y_label_rotation:
-        @param z_label:
-        @param z_label_bold:
-        @param z_label_size:
-        @param z_label_pad:
-        @param z_label_rotation:
-        @param x_tick_number:
-        @param x_tick_labels:
-        @param y_tick_number:
-        @param y_tick_labels:
-        @param z_tick_number:
-        @param z_tick_labels:
-        @param x_tick_rotation:
-        @param y_tick_rotation:
-        @param z_tick_rotation:
-        @param tick_color:
-        @param tick_label_pad:
-        @param tick_ndecimals:
-        @param tick_label_size:
-        @param tick_label_size_x:
-        @param tick_label_size_y:
-        @param tick_label_size_z:
-        @param color_bar:
-        @param extend:
-        @param shrink:
-        @param cb_title:
-        @param cb_axis_labelpad:
-        @param cb_tick_number:
-        @param cb_outline_width:
-        @param cb_title_rotation:
-        @param cb_title_style:
-        @param cb_title_size:
-        @param cb_top_title_y:
-        @param cb_ytitle_labelpad:
-        @param cb_title_weight:
-        @param cb_top_title:
-        @param cb_y_title:
-        @param cb_top_title_pad:
-        @param cb_top_title_x:
-        @param cb_vmin:
-        @param cb_vmax:
-        @param cb_ticklabelsize:
-        @param legend:
-        @param legend_loc:
-        @param legend_size:
-        @param legend_weight:
-        @param legend_style:
-        @param legend_handleheight:
-        @param legend_ncol:
-        @param more_subplots_left:
-        @param newplot:
-        @param filename:
-        @param dpi:
+        Line plot class
+        mpl_plotter - 3D
         """
 
         # Turn all instance arguments to instance attributes
@@ -527,9 +430,9 @@ class surface(plot, dim_2):
                  # Specifics: color
                  norm=None, c=None,
                  # Base
-                 backend='Qt5Agg', plot_label='Plot', font='serif',
+                 backend='Qt5Agg', plot_label='Surface', font='serif',
                  # Figure, axis
-                 fig=None, ax=None, figsize=None, shape_and_position=111,
+                 fig=None, ax=None, figsize=None, shape_and_position=111, azim=None, elev=None,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10, spines_removed=('top', 'right'),
                  workspace_color=None, workspace_color2=None, light=None, dark=None, pane_fill=None,
@@ -543,11 +446,11 @@ class surface(plot, dim_2):
                  color='darkred', cmap='RdBu_r', alpha=None,
                  # Bounds
                  # Title
-                 title='Title', title_bold=False, title_size=12, title_y=1.025,
+                 title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=5, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=5, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=5, z_label_rotation=None,
+                 x_label=None, x_label_weight=None, x_label_size=12, x_label_pad=5, x_label_rotation=None,
+                 y_label=None, y_label_weight=None, y_label_size=12, y_label_pad=5, y_label_rotation=None,
+                 z_label=None, z_label_weight=None, z_label_size=12, z_label_pad=5, z_label_rotation=None,
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
@@ -567,123 +470,13 @@ class surface(plot, dim_2):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=False, newplot=False,
+                 more_subplots_left=True,
                  # Save
                  filename=None, dpi=None,
                  ):
         """
-
-        @param x:
-        @param x_scale:
-        @param y:
-        @param y_scale:
-        @param z:
-        @param z_scale:
-        @param edge_color:
-        @param edges_to_rgba:
-        @param rstride:
-        @param cstride:
-        @param line_width:
-        @param lighting:
-        @param antialiased:
-        @param shade:
-        @param norm:
-        @param c:
-        @param backend:
-        @param plot_label:
-        @param font:
-        @param fig:
-        @param ax:
-        @param figsize:
-        @param shape_and_position:
-        @param prune:
-        @param resize_axes:
-        @param aspect:
-        @param box_to_plot_pad:
-        @param spines_removed:
-        @param workspace_color:
-        @param workspace_color2:
-        @param light:
-        @param dark:
-        @param pane_fill:
-        @param x_bounds:
-        @param y_bounds:
-        @param z_bounds:
-        @param x_pad:
-        @param y_pad:
-        @param z_pad:
-        @param grid:
-        @param grid_color:
-        @param grid_lines:
-        @param color:
-        @param cmap:
-        @param alpha:
-        @param title:
-        @param title_bold:
-        @param title_size:
-        @param title_y:
-        @param x_label:
-        @param x_label_bold:
-        @param x_label_size:
-        @param x_label_pad:
-        @param x_label_rotation:
-        @param y_label:
-        @param y_label_bold:
-        @param y_label_size:
-        @param y_label_pad:
-        @param y_label_rotation:
-        @param z_label:
-        @param z_label_bold:
-        @param z_label_size:
-        @param z_label_pad:
-        @param z_label_rotation:
-        @param x_tick_number:
-        @param x_tick_labels:
-        @param y_tick_number:
-        @param y_tick_labels:
-        @param z_tick_number:
-        @param z_tick_labels:
-        @param x_tick_rotation:
-        @param y_tick_rotation:
-        @param z_tick_rotation:
-        @param tick_color:
-        @param tick_label_pad:
-        @param tick_ndecimals:
-        @param tick_label_size:
-        @param tick_label_size_x:
-        @param tick_label_size_y:
-        @param tick_label_size_z:
-        @param color_bar:
-        @param extend:
-        @param shrink:
-        @param cb_title:
-        @param cb_axis_labelpad:
-        @param cb_tick_number:
-        @param cb_outline_width:
-        @param cb_title_rotation:
-        @param cb_title_style:
-        @param cb_title_size:
-        @param cb_top_title_y:
-        @param cb_ytitle_labelpad:
-        @param cb_title_weight:
-        @param cb_top_title:
-        @param cb_y_title:
-        @param cb_top_title_pad:
-        @param cb_top_title_x:
-        @param cb_vmin:
-        @param cb_vmax:
-        @param cb_ticklabelsize:
-        @param legend:
-        @param legend_loc:
-        @param legend_size:
-        @param legend_weight:
-        @param legend_style:
-        @param legend_handleheight:
-        @param legend_ncol:
-        @param more_subplots_left:
-        @param newplot:
-        @param filename:
-        @param dpi:
+        Surface plot class
+        mpl_plotter - 3D
         """
 
         # Turn all instance arguments to instance attributes
@@ -702,7 +495,10 @@ class surface(plot, dim_2):
                                           edgecolors=self.edge_color, alpha=self.alpha,
                                           rstride=self.rstride, cstride=self.cstride, linewidth=self.line_width,
                                           norm=self.norm, facecolors=self.method_lighting() if self.lighting is True else None,
-                                          antialiased=self.antialiased, shade=self.shade)
+                                          antialiased=self.antialiased, shade=self.shade,
+                                          label=self.plot_label)
+        self.graph._facecolors2d = self.graph._facecolors3d
+        self.graph._edgecolors2d = self.graph._edgecolors3d
 
     def mock(self):
         if isinstance(self.x, type(None)) and isinstance(self.y, type(None)) and isinstance(self.z, type(None)):
